{ pkgs, ... }:
let
  home-manager = builtins.fetchTarball "https://github.com/nix-community/home-manager/archive/master.tar.gz";
  arkenfox = builtins.fetchTarball "https://github.com/arkenfox/user.js/archive/master.tar.gz";
in
{
  imports =
    [ # Include the results of the hardware scan.
      (import "${home-manager}/nixos")
    ];
  nixpkgs.config.packageOverrides = pkgs: {
    nur = import (builtins.fetchTarball "https://github.com/nix-community/NUR/archive/master.tar.gz") {
      inherit pkgs;
    };
  };
  home-manager.users.ark.programs.firefox = {
    enable = true;
    profiles.default = {
      id = 0;
      name = "default";
      isDefault = true;
      search.force = true;
      search.default = "LibRedirect";
      search.privateDefault = "LibRedirect";
      settings = {
        "toolkit.legacyUserProfileCustomizations.stylesheets" = true;
        "browser.toolbars.bookmarks.visibility" = "never";
        "signon.rememberSignons" = false;
      };
      containersForce = true;
      containers = {
        "school" = {
          id = 0;
          color = "red";
          icon = "fruit";
        };
      };
      extensions = with pkgs.nur.repos.rycee.firefox-addons; [
        ublock-origin
        bitwarden
        libredirect
        sidebery
        stylus
        firefox-color
        tabliss
      ];
      bookmarks = [
        {
          name = "nixos";
          bookmarks = [
            {
              name = "nixos packages";
              url = "https://search.nixos.org";
            }
            {
              name = "home manager wiki";
              url = "https://nix-community.github.io/home-manager";
            }
          ];
        }
      ];
      userChrome = builtins.readFile ./userChrome.css;
      extraConfig = builtins.readFile "${arkenfox}/user.js";
    };
  };
}
